import {FC, useEffect, useState} from "react";
import Taro, {useReachBottom} from "@tarojs/taro";
import {View} from "@tarojs/components";
import {Courses, CoursesKey, publicApi} from "@/api/public";
import VideoCover from "@/components/videoCover/videoCover";
import styles from '../index.module.scss'
import {formatMinute} from "@/utils/time";
import {userApi} from "@/api";
import Empty from "@/components/empty/empty";

interface Props {
  categoryKey: CoursesKey
}

export const VideoList: FC<Props> = ({categoryKey}) => {
  const [init, setInit] = useState(false)
  const [data, setData] = useState<Courses>({
    is_finished: [],
    is_required: [],
    is_not_finished: [],
    is_not_required: []
  })
  const [page, setPage] = useState(1)
  const [records, setRecords] = useState<LearnRecord[]>([])


  async function getData() {
    try {
      const res = await publicApi.course({page: 1, pageSize: 10 * page})
      setData(res)
    } catch (e) {
    }
  }

  async function getRecords() {
    try {
      const {user_course_records} = await userApi.learningRecord()
      setRecords(user_course_records)
    } catch (e) {
    }
  }


  function rateOfLearning(id: number, class_hour: number): JSX.Element {
    switch (categoryKey) {
      case "is_required":
      case "is_not_required":
      case "is_not_finished":
        const find = records.find(d => d?.course_id === id)
        if (find) {
          if (class_hour === find.finished_count) {
            return <View>已完成</View>
          }
          return (<View>{`共${class_hour}节/已学${find.finished_count}节`}</View>)
        }
        return (<View>{`共${class_hour}节/已学0节`}</View>)
      case "is_finished":
        return <View>已完成</View>
    }
    return (<View>sd</View>)
  }

  useReachBottom(() => {
    setPage(page + 1)
  })

  // eventsIndex.on(()=>{
  //   getRecords()
  // })

  Taro.useDidShow(() => {
    if (init) {
      getData()
    }
    getRecords()
  })

  useEffect(() => {
    setInit(true)
    getData()
  }, [page])
  return (
    <View className={'py-2 flex justify-between flex-wrap ' + styles.videoListBox}>
      {data?.[categoryKey]?.length ? data?.[categoryKey]?.map(c =>
        <VideoCover
          thumb={c.thumb}
          title={c.title}
          id={c.id}
          depId={c.id}
          key={c.id}
          time={formatMinute(c.course_duration)}
          content={rateOfLearning(c.id, c.class_hour)}
        />) : <Empty name='暂无数据'/>}
    </View>
  )
}

