import {Image, View} from "@tarojs/components";
import styles from '../../my.module.scss'
import curriculum1 from '@/static/img/curriculum1.png'
import curriculum2 from '@/static/img/curriculum2.png'
import Taro from "@tarojs/taro";
import {curriculum} from "@/api";
import {FC, useState} from "react";
import {formatMinute} from "@/utils/time";
import time1 from "@/static/img/time1.png";
import time2 from "@/static/img/time2.png";
import over from '@/static/img/over.png'
import incomplete from '@/static/img/incomplete.png'

interface List {
  title: string
  time: string | number
  src: string
}

const Time:FC = () => {
  const [list, setList] = useState<List[]>([
    {title: '今日时长', time: '00:00', src: time1},
    {title: '累计时长', time: '00:00', src: time2},
    {title: '必修课', time: '0/0', src: curriculum1},
    {title: '选修课', time: '0/0', src: curriculum2},
    {title: '已完成', time: '0', src: over},
    {title: '未完成', time: '0', src: incomplete},
  ])


  Taro.useDidShow(async () => {
    try {
      const {stats} = await curriculum.course()
      const oldList: List[] = JSON.parse(JSON.stringify(list))
      oldList[0].time = formatMinute(stats.today_learn_duration)
      oldList[1].time = formatMinute(stats.learn_duration)
      oldList[2].time = stats.required_course_count
      oldList[3].time = stats.nun_required_course_count
      oldList[4].time = stats.required_finished_course_count + stats.nun_required_finished_course_count
      oldList[5].time = stats.total_course_count - (stats.required_finished_course_count + stats.nun_required_finished_course_count)
      setList(oldList)
    } catch (e) {}
  })


  return (
    <View className='flex mt-3 justify-between flex-wrap'>
      {
        list.map(d => {
          return (
            <View className={'flex justify-between ' + styles.timeBox} key={d.title}>
              <View>
                <View className='font-weight mb-2'>{d.title}</View>
                <View className='text-muted font-26'>{d.time}</View>
              </View>
              <Image src={d.src} mode='aspectFit' className={styles.timeImag}/>
            </View>
          )
        })
      }
    </View>
  )
}

export default Time
