import {useEffect, useState} from "react";
import {createContainer} from "unstated-next";
import Taro from "@tarojs/taro";


function useProfile() {
  let data
  try {
    data = JSON.parse(Taro.getStorageSync('profile') || '{}')
  } catch (e) {
    console.error(e)
  }

  const [role, setRole] = useState<UserRole | null>(data?.role || null)
  const [user, setUser] = useState<User | null>(data?.user || null)
  const [token, setToken] = useState<string | null>(data?.token || null)
  const [company, setCompany] = useState<Company | null>(data?.company || null)


  function empty() {
    setUser(null)
    setUser(null)
    setToken(null)
    Taro.removeStorageSync('profile')
    // Taro.reLaunch({url: '/pages/login/login'})
  }

  useEffect(() => {
    Taro.setStorage({
      key: 'profile',
      data: JSON.stringify({role, user, token, company})
    })
  }, [role, user, token, company])

  return {
    role, setRole,
    user, setUser,
    token, setToken,
    company, setCompany,
    empty
  }
}

export const Profile = createContainer(useProfile);
